@@ -16,18 +16,18 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
-import logging
 import cmath
+import logging
 import math
 import os
 import re
-from collections import defaultdict, UserDict
+from collections import UserDict, defaultdict
 from dataclasses import dataclass
 
 from scipy.interpolate import interp1d
 
 from NanoVNASaver.RFTools import Datapoint
-
+from NanoVNASaver.Touchstone import Touchstone
 
 IDEAL_SHORT = complex(-1, 0)
 IDEAL_OPEN = complex(1, 0)
@@ -111,6 +111,8 @@ class CalData:
 @dataclass
 class CalElement:
     # pylint: disable=too-many-instance-attributes
+    short_state: str = ""
+    short_touchstone: Touchstone = None
     short_is_ideal: bool = True
     short_l0: float = 5.7e-12
     short_l1: float = -8.96e-20
@@ -118,6 +120,8 @@ class CalElement:
     short_l3: float = -4.12e-37
     short_length: float = -34.2  # ps
 
+    open_state: str = ""
+    open_touchstone: Touchstone = None
     open_is_ideal: bool = True
     open_c0: float = 2.1e-14
     open_c1: float = 5.67e-23
@@ -125,6 +129,8 @@ class CalElement:
     open_c3: float = 2.0e-40
     open_length: float = 0.0
 
+    load_state: str = ""
+    load_touchstone: Touchstone = None
     load_is_ideal: bool = True
     load_r: float = 50.0
     load_l: float = 0.0
@@ -194,7 +200,7 @@ class CalDataSet(UserDict):
         header = ""
         # parse text
         for i, line in enumerate(text.splitlines(), 1):
-            line = line.strip()
+            line = line.strip()  # noqa: PLW2901
 
             if line.startswith("!"):
                 self.notes += f"{line[2:]}\n"
@@ -368,8 +374,12 @@ class Calibration:
         logger.debug("Calibration correctly calculated.")
 
     def gamma_short(self, freq: int) -> complex:
-        if self.cal_element.short_is_ideal:
+        if self.cal_element.short_state == "IDEAL":
             return IDEAL_SHORT
+        if self.cal_element.short_state == "FILE":
+            self.cal_element.short_touchstone.gen_interpolation_s11()
+            dp = self.cal_element.short_touchstone.s_freq("11", freq)
+            return complex(dp.re, dp.im)
         logger.debug("Using short calibration set values.")
         cal_element = self.cal_element
         Zsp = complex(
@@ -394,8 +404,12 @@ class Calibration:
         )
 
     def gamma_open(self, freq: int) -> complex:
-        if self.cal_element.open_is_ideal:
+        if self.cal_element.open_state == "IDEAL":
             return IDEAL_OPEN
+        if self.cal_element.open_state == "FILE":
+            self.cal_element.open_touchstone.gen_interpolation_s11()
+            dp = self.cal_element.open_touchstone.s_freq("11", freq)
+            return complex(dp.re, dp.im)
         logger.debug("Using open calibration set values.")
         cal_element = self.cal_element
         Zop = complex(
@@ -415,8 +429,12 @@ class Calibration:
         )
 
     def gamma_load(self, freq: int) -> complex:
-        if self.cal_element.load_is_ideal:
+        if self.cal_element.load_state == "IDEAL":
             return IDEAL_LOAD
+        if self.cal_element.load_state == "FILE":
+            self.cal_element.load_touchstone.gen_interpolation_s11()
+            dp = self.cal_element.load_touchstone.s_freq("11", freq)
+            return complex(dp.re, dp.im)
         logger.debug("Using load calibration set values.")
         cal_element = self.cal_element
         Zl = complex(cal_element.load_r, 0.0)
@@ -458,7 +476,8 @@ class Calibration:
                     c.e10e32,
                 )
                 for c in self.dataset.values()
-            ]
+            ],
+            strict=False,
         )
 
         self.interp = {
