@@ -16,8 +16,8 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
-import math
 import logging
+import math
 
 import numpy as np
 from PyQt6.QtCore import QPoint, QRect, Qt
@@ -25,9 +25,9 @@ from PyQt6.QtGui import (
     QAction,
     QActionGroup,
     QMouseEvent,
-    QPalette,
     QPainter,
     QPaintEvent,
+    QPalette,
     QPen,
     QResizeEvent,
 )
@@ -48,22 +48,20 @@ MAX_VSWR = 10
 
 
 class TDRChart(Chart):
-    maxDisplayLength = 50
-    minDisplayLength = 0
-    fixedSpan = False
+    max_display_length: int = 50
+    min_display_length: int = 0
+    fixed_span: bool = False
 
-    minYlim = 0
-    maxYlim = 1000
+    min_y_lim: float = 0.0
+    max_y_lim: float = 1000.0
 
-    decimals = 1
+    decimals: int = 1
 
-    formatString = ""
+    format_string: str = ""
+    fixed_values: bool = False
+    marker_location: int = -1
 
-    fixedValues = False
-
-    markerLocation = -1
-
-    def __init__(self, name):
+    def __init__(self, name) -> None:  # noqa: PLR0915
         super().__init__(name)
         self.tdrWindow = None
 
@@ -109,11 +107,13 @@ class TDRChart(Chart):
         self.x_menu.addSeparator()
 
         self.action_set_fixed_start = QAction(
-            f"Start ({self.minDisplayLength})"
+            f"Start ({self.min_display_length})"
         )
         self.action_set_fixed_start.triggered.connect(self.setMinimumLength)
 
-        self.action_set_fixed_stop = QAction(f"Stop ({self.maxDisplayLength})")
+        self.action_set_fixed_stop = QAction(
+            f"Stop ({self.max_display_length})"
+        )
         self.action_set_fixed_stop.triggered.connect(self.setMaximumLength)
 
         self.x_menu.addAction(self.action_set_fixed_start)
@@ -138,10 +138,10 @@ class TDRChart(Chart):
         self.y_menu.addAction(self.y_action_fixed)
         self.y_menu.addSeparator()
 
-        self.y_action_set_fixed_maximum = QAction(f"Maximum ({self.maxYlim})")
+        self.y_action_set_fixed_maximum = QAction(f"Maximum ({self.max_y_lim})")
         self.y_action_set_fixed_maximum.triggered.connect(self.setMaximumY)
 
-        self.y_action_set_fixed_minimum = QAction(f"Minimum ({self.minYlim})")
+        self.y_action_set_fixed_minimum = QAction(f"Minimum ({self.min_y_lim})")
         self.y_action_set_fixed_minimum.triggered.connect(self.setMinimumY)
 
         self.y_menu.addAction(self.y_action_set_fixed_maximum)
@@ -153,135 +153,138 @@ class TDRChart(Chart):
         self.menu.addAction(self.action_save_screenshot)
         self.action_popout = QAction("Popout chart")
         self.action_popout.triggered.connect(
-            lambda: self.popoutRequested.emit(self)
+            lambda: self.popout_requested.emit(self)
         )
         self.menu.addAction(self.action_popout)
 
         self.dim.width = self.width() - self.leftMargin - self.rightMargin
         self.dim.height = self.height() - self.bottomMargin - self.topMargin
 
-    def contextMenuEvent(self, event):
-        self.action_set_fixed_start.setText(f"Start ({self.minDisplayLength})")
-        self.action_set_fixed_stop.setText(f"Stop ({self.maxDisplayLength})")
-        self.y_action_set_fixed_minimum.setText(f"Minimum ({self.minYlim})")
-        self.y_action_set_fixed_maximum.setText(f"Maximum ({self.maxYlim})")
+    def contextMenuEvent(self, event) -> None:
+        self.action_set_fixed_start.setText(
+            f"Start ({self.min_display_length})"
+        )
+        self.action_set_fixed_stop.setText(f"Stop ({self.max_display_length})")
+        self.y_action_set_fixed_minimum.setText(f"Minimum ({self.min_y_lim})")
+        self.y_action_set_fixed_maximum.setText(f"Maximum ({self.max_y_lim})")
         self.menu.exec(event.globalPos())
 
-    def isPlotable(self, x, y):
+    def isPlotable(self, x, y) -> bool:
         return (
             self.leftMargin <= x <= self.width() - self.rightMargin
             and self.topMargin <= y <= self.height() - self.bottomMargin
         )
 
-    def _configureGraphFromFormat(self):
-        TDR_format = self.tdrWindow.format_dropdown.currentText()
-        if TDR_format == "|Z|":
-            self.minYlim = MIN_IMPEDANCE
-            self.maxYlim = MAX_IMPEDANCE
-            self.formatString = "impedance (\N{OHM SIGN})"
-            self.decimals = 1
-        elif TDR_format == "S11":
-            self.minYlim = MIN_S11
-            self.maxYlim = MAX_S11
-            self.formatString = "S11 (dB)"
-            self.decimals = 1
-        elif TDR_format == "VSWR":
-            self.minYlim = MIN_VSWR
-            self.maxYlim = MAX_VSWR
-            self.formatString = "VSWR"
-            self.decimals = 2
+    def _configureGraphFromFormat(self) -> None:
+        FORMAT_DEFAULTS = {
+            "|Z| (lowpass)": (
+                MIN_IMPEDANCE,
+                MAX_IMPEDANCE,
+                "impedance (\N{OHM SIGN})",
+                1,
+            ),
+            "S11 (lowpass)": (MIN_S11, MIN_S11, "S11 (dB)", 1),
+            "VSWR (lowpass)": (MIN_VSWR, MIN_VSWR, "VSWR", 2),
+            "Refl (lowpass)": (-1, 1, "U", 2),
+            "Refl (bandpass)": (0, 1, "U", 2),
+        }
+        self.min_y_lim, self.max_y_lim, self.format_string, self.decimals = (
+            FORMAT_DEFAULTS[self.tdrWindow.format_dropdown.currentText()]
+        )
 
-    def resetDisplayLimits(self):
+    def resetDisplayLimits(self) -> None:
         self._configureGraphFromFormat()
-        self.fixedSpan = False
-        self.minDisplayLength = 0
-        self.maxDisplayLength = 100
-        self.fixedValues = False
+        self.fixed_span = False
+        self.min_display_length = 0
+        self.max_display_length = 100
+        self.fixed_values = False
         self.update()
 
-    def setFixedSpan(self, fixed_span):
-        self.fixedSpan = fixed_span
+    def setFixedSpan(self, fixed_span) -> None:
+        self.fixed_span = fixed_span
         self.update()
 
-    def setMinimumLength(self):
+    def setMinimumLength(self) -> None:
         min_val, selected = QInputDialog.getDouble(
             self,
             "Start length (m)",
             "Set start length (m)",
-            value=self.minDisplayLength,
+            value=self.min_display_length,
             min=0,
             decimals=1,
         )
         if not selected:
             return
-        if not (self.fixedSpan and min_val >= self.maxDisplayLength):
-            self.minDisplayLength = min_val
-        if self.fixedSpan:
+        if not (self.fixed_span and min_val >= self.max_display_length):
+            self.min_display_length = min_val
+        if self.fixed_span:
             self.update()
 
-    def setMaximumLength(self):
+    def setMaximumLength(self) -> None:
         max_val, selected = QInputDialog.getDouble(
             self,
             "Stop length (m)",
             "Set stop length (m)",
-            value=self.maxDisplayLength,
+            value=self.max_display_length,
             min=0.1,
             decimals=1,
         )
         if not selected:
             return
-        if not (self.fixedSpan and max_val <= self.minDisplayLength):
-            self.maxDisplayLength = max_val
-        if self.fixedSpan:
+        if not (self.fixed_span and max_val <= self.min_display_length):
+            self.max_display_length = max_val
+        if self.fixed_span:
             self.update()
 
-    def setFixedValues(self, fixed_values):
-        self.fixedValues = fixed_values
+    def setFixedValues(self, fixed_values) -> None:
+        self.fixed_values = fixed_values
         self.update()
 
-    def setMinimumY(self):
+    def setMinimumY(self) -> None:
         min_val, selected = QInputDialog.getDouble(
             self,
-            "Minimum " + self.formatString,
-            "Set minimum " + self.formatString,
-            value=self.minYlim,
+            "Minimum " + self.format_string,
+            "Set minimum " + self.format_string,
+            value=self.min_y_lim,
             decimals=self.decimals,
         )
         if not selected:
             return
-        if not (self.fixedValues and min_val >= self.maxYlim):
-            self.minYlim = min_val
-        if self.fixedValues:
+        if not (self.fixed_values and min_val >= self.max_y_lim):
+            self.min_y_lim = min_val
+        if self.fixed_values:
             self.update()
 
-    def setMaximumY(self):
+    def setMaximumY(self) -> None:
         max_val, selected = QInputDialog.getDouble(
             self,
-            "Maximum " + self.formatString,
-            "Set maximum " + self.formatString,
-            value=self.maxYlim,
+            "Maximum " + self.format_string,
+            "Set maximum " + self.format_string,
+            value=self.max_y_lim,
             decimals=self.decimals,
         )
         if not selected:
             return
-        if not (self.fixedValues and max_val <= self.minYlim):
-            self.maxYlim = max_val
-        if self.fixedValues:
+        if not (self.fixed_values and max_val <= self.min_y_lim):
+            self.max_y_lim = max_val
+        if self.fixed_values:
             self.update()
 
-    def copy(self):
+    def copy(self) -> "TDRChart":
         new_chart: TDRChart = super().copy()
         new_chart.tdrWindow = self.tdrWindow
-        new_chart.minDisplayLength = self.minDisplayLength
-        new_chart.maxDisplayLength = self.maxDisplayLength
-        new_chart.fixedSpan = self.fixedSpan
-        new_chart.minYlim = self.minYlim
-        new_chart.maxYlim = self.maxYlim
-        new_chart.fixedValues = self.fixedValues
+        new_chart.min_display_length = self.min_display_length
+        new_chart.max_display_length = self.max_display_length
+        new_chart.fixed_span = self.fixed_span
+        new_chart.min_y_lim = self.min_y_lim
+        new_chart.max_y_lim = self.max_y_lim
+        new_chart.fixed_values = self.fixed_values
         self.tdrWindow.updated.connect(new_chart.update)
         return new_chart
 
     def mouseMoveEvent(self, a0: QMouseEvent) -> None:
+        if not hasattr(self.tdrWindow, "td"):
+            return
         if a0.buttons() == Qt.MouseButton.RightButton:
             a0.ignore()
             return
@@ -316,24 +319,21 @@ class TDRChart(Chart):
             return
         a0.accept()
         width = self.width() - self.leftMargin - self.rightMargin
-        if self.tdrWindow.td:
-            if self.fixedSpan:
-                max_index = np.searchsorted(
-                    self.tdrWindow.distance_axis, self.maxDisplayLength * 2
-                )
-                min_index = np.searchsorted(
-                    self.tdrWindow.distance_axis, self.minDisplayLength * 2
-                )
-                x_step = (max_index - min_index) / width
-            else:
-                max_index = math.ceil(len(self.tdrWindow.distance_axis) / 2)
-                x_step = max_index / width
+        if self.fixed_span:
+            max_index = np.searchsorted(
+                self.tdrWindow.distance_axis, self.max_display_length * 2
+            )
+            min_index = np.searchsorted(
+                self.tdrWindow.distance_axis, self.min_display_length * 2
+            )
+            x_step = (max_index - min_index) / width
+        else:
+            x_step = math.ceil(len(self.tdrWindow.distance_axis) / 2) / width
 
-            self.markerLocation = int(round(absx * x_step))
-            self.update()
-        return
+        self.marker_location = int(round(absx * x_step))
+        self.update()
 
-    def _draw_ticks(self, height, width, x_step, min_index):
+    def _draw_ticks(self, height, width, x_step, min_index) -> None:
         ticks = (self.width() - self.leftMargin) // 100
         qp = QPainter(self)
         for i in range(ticks):
@@ -354,10 +354,14 @@ class TDRChart(Chart):
         qp.drawText(
             self.leftMargin - 10,
             self.topMargin + height + 15,
-            f"{str(round(self.tdrWindow.distance_axis[min_index] / 2, self.decimals))}m",
+            f"""{str(round(
+                self.tdrWindow.distance_axis[min_index] / 2, self.decimals))
+                }m""",
         )
 
-    def _draw_y_ticks(self, height, width, min_impedance, max_impedance):
+    def _draw_y_ticks(
+        self, height, width, min_impedance, max_impedance
+    ) -> None:
         qp = QPainter(self)
         y_step = (max_impedance - min_impedance) / height
         y_ticks = math.floor(height / 60)
@@ -376,13 +380,14 @@ class TDRChart(Chart):
             f"{round(min_impedance, self.decimals)}",
         )
 
-    def _draw_max_point(self, height, x_step, y_step, min_index):
+    def _draw_max_point(self, height, x_step, y_step, min_index) -> None:
         qp = QPainter(self)
         id_max = np.argmax(self.tdrWindow.td)
 
         max_point = QPoint(
             self.leftMargin + int((id_max - min_index) / x_step),
-            (self.topMargin + height) - int(self.tdrWindow.td[id_max] / y_step),
+            (self.topMargin + height)
+            - int(np.real(self.tdrWindow.td[id_max]) / y_step),
         )
 
         qp.setPen(self.markers[0].color)
@@ -397,9 +402,9 @@ class TDRChart(Chart):
     def _draw_marker(self, height, x_step, y_step, min_index):
         qp = QPainter(self)
         marker_point = QPoint(
-            self.leftMargin + int((self.markerLocation - min_index) / x_step),
+            self.leftMargin + int((self.marker_location - min_index) / x_step),
             (self.topMargin + height)
-            - int(self.tdrWindow.td[self.markerLocation] / y_step),
+            - int(float(self.tdrWindow.td[self.marker_location]) / y_step),
         )
         qp.setPen(Chart.color.text)
         qp.drawEllipse(marker_point, 2, 2)
@@ -407,7 +412,7 @@ class TDRChart(Chart):
             marker_point.x() - 10,
             marker_point.y() - 5,
             f"""{round(
-                    self.tdrWindow.distance_axis[self.markerLocation] / 2,
+                    self.tdrWindow.distance_axis[self.marker_location] / 2,
                     2)}m""",
         )
 
@@ -415,13 +420,13 @@ class TDRChart(Chart):
         min_index = 0
         max_index = math.ceil(len(self.tdrWindow.distance_axis) / 2)
 
-        if self.fixedSpan:
-            max_length = max(0.1, self.maxDisplayLength)
+        if self.fixed_span:
+            max_length = max(0.1, self.max_display_length)
             max_index = np.searchsorted(
                 self.tdrWindow.distance_axis, max_length * 2
             )
             min_index = np.searchsorted(
-                self.tdrWindow.distance_axis, self.minDisplayLength * 2
+                self.tdrWindow.distance_axis, self.min_display_length * 2
             )
             if max_index == min_index:
                 if max_index < len(self.tdrWindow.distance_axis) - 1:
@@ -434,11 +439,11 @@ class TDRChart(Chart):
         min_Z = np.min(self.tdrWindow.step_response_Z)
         max_Z = np.max(self.tdrWindow.step_response_Z)
         # Ensure that everything works even if limits are negative
-        min_impedance = max(self.minYlim, min_Z - 0.05 * np.abs(min_Z))
-        max_impedance = min(self.maxYlim, max_Z + 0.05 * np.abs(max_Z))
-        if self.fixedValues:
-            min_impedance = self.minYlim
-            max_impedance = self.maxYlim
+        min_impedance = max(self.min_y_lim, min_Z - 0.05 * np.abs(min_Z))
+        max_impedance = min(self.max_y_lim, max_Z + 0.05 * np.abs(max_Z))
+        if self.fixed_values:
+            min_impedance = self.min_y_lim
+            max_impedance = self.max_y_lim
 
         y_step = max(self.tdrWindow.td) * 1.1 / height or 1.0e-30
 
@@ -453,7 +458,9 @@ class TDRChart(Chart):
         y_step = (max_impedance - min_impedance) / height
         for i in range(min_index, max_index):
             x = self.leftMargin + int((i - min_index) / x_step)
-            y = (self.topMargin + height) - int(self.tdrWindow.td[i] / y_step)
+            y = (self.topMargin + height) - int(
+                np.real(self.tdrWindow.td[i]) / y_step
+            )
             if self.isPlotable(x, y):
                 pen.setColor(Chart.color.sweep)
                 qp.setPen(pen)
@@ -470,7 +477,7 @@ class TDRChart(Chart):
 
         self._draw_max_point(height, x_step, y_step, min_index)
 
-        if self.markerLocation != -1:
+        if self.marker_location != -1:
             self._draw_marker(height, x_step, y_step, min_index)
 
     def paintEvent(self, _: QPaintEvent) -> None:
@@ -497,7 +504,7 @@ class TDRChart(Chart):
         # Number of ticks does not include the origin
         self.drawTitle(qp)
 
-        if self.tdrWindow.td:
+        if hasattr(self.tdrWindow, "td"):
             self._draw_graph(height, width)
 
         if self.dragbox.state and self.dragbox.pos[0] != -1:
@@ -512,32 +519,36 @@ class TDRChart(Chart):
 
         qp.end()
 
-    def valueAtPosition(self, y):
-        if self.tdrWindow.td:
+    def valueAtPosition(self, y: int) -> float:
+        if hasattr(self.tdrWindow, "td"):
             height = self.height() - self.topMargin - self.bottomMargin
             absy = (self.height() - y) - self.bottomMargin
-            if self.fixedValues:
-                min_impedance = self.minYlim
-                max_impedance = self.maxYlim
+            if self.fixed_values:
+                min_impedance = self.min_y_lim
+                max_impedance = self.max_y_lim
             else:
-                min_Z = np.min(self.tdrWindow.step_response_Z)
-                max_Z = np.max(self.tdrWindow.step_response_Z)
+                min_Z = float(np.min(self.tdrWindow.step_response_Z))
+                max_Z = float(np.max(self.tdrWindow.step_response_Z))
                 # Ensure that everything works even if limits are negative
-                min_impedance = max(self.minYlim, min_Z - 0.05 * np.abs(min_Z))
-                max_impedance = min(self.maxYlim, max_Z + 0.05 * np.abs(max_Z))
+                min_impedance = max(
+                    self.min_y_lim, min_Z - 0.05 * float(np.abs(min_Z))
+                )
+                max_impedance = min(
+                    self.max_y_lim, max_Z + 0.05 * float(np.abs(max_Z))
+                )
             y_step = (max_impedance - min_impedance) / height
             return y_step * absy + min_impedance
-        return 0
+        return 0.0
 
-    def lengthAtPosition(self, x, limit=True):
-        if not self.tdrWindow.td:
+    def lengthAtPosition(self, x: int, limit=True):
+        if not hasattr(self.tdrWindow, "td"):
             return 0
         width = self.width() - self.leftMargin - self.rightMargin
         absx = x - self.leftMargin
-        min_length = self.minDisplayLength if self.fixedSpan else 0
+        min_length = self.min_display_length if self.fixed_span else 0
         max_length = (
-            self.maxDisplayLength
-            if self.fixedSpan
+            self.max_display_length
+            if self.fixed_span
             else (
                 self.tdrWindow.distance_axis[
                     math.ceil(len(self.tdrWindow.distance_axis) / 2)
@@ -546,14 +557,14 @@ class TDRChart(Chart):
             )
         )
 
-        x_step = (max_length - min_length) / width
+        x_step = float(max_length - min_length) / width
         if limit and absx < 0:
-            return min_length
-        return (
+            return float(min_length)
+        return float(
             max_length if limit and absx > width else absx * x_step + min_length
         )
 
-    def zoomTo(self, x1, y1, x2, y2):
+    def zoomTo(self, x1, y1, x2, y2) -> None:
         logger.debug(
             "Zoom to (x,y) by (x,y): (%d, %d) by (%d, %d)", x1, y1, x2, y2
         )
@@ -561,16 +572,16 @@ class TDRChart(Chart):
         val2 = self.valueAtPosition(y2)
 
         if val1 != val2:
-            self.minYlim = round(min(val1, val2), 3)
-            self.maxYlim = round(max(val1, val2), 3)
+            self.min_y_lim = round(min(val1, val2), 3)
+            self.max_y_lim = round(max(val1, val2), 3)
             self.setFixedValues(True)
 
         len1 = max(0, self.lengthAtPosition(x1, limit=False))
         len2 = max(0, self.lengthAtPosition(x2, limit=False))
 
         if len1 >= 0 and len2 >= 0 and len1 != len2:
-            self.minDisplayLength = min(len1, len2)
-            self.maxDisplayLength = max(len1, len2)
+            self.min_display_length = min(len1, len2)
+            self.max_display_length = max(len1, len2)
             self.setFixedSpan(True)
 
         self.update()
