@@ -20,62 +20,63 @@ import contextlib
 import logging
 import sys
 import threading
-from time import strftime, localtime
+from time import localtime, strftime
 
-from PyQt6 import QtWidgets, QtCore, QtGui
+from PyQt6 import QtCore, QtGui, QtWidgets
 from PyQt6.QtCore import QObject
 from PyQt6.QtWidgets import QWidget
 
 from NanoVNASaver import Defaults
-from .Windows import (
-    AboutWindow,
-    AnalysisWindow,
-    CalibrationWindow,
-    DeviceSettingsWindow,
-    DisplaySettingsWindow,
-    SweepSettingsWindow,
-    TDRWindow,
-    FilesWindow,
-)
-from .Controls.MarkerControl import MarkerControl
-from .Controls.SweepControl import SweepControl
-from .Controls.SerialControl import SerialControl
-from .Formatting import format_frequency, format_vswr, format_gain
-from .Hardware.Hardware import Interface
-from .Hardware.VNA import VNA
-from .RFTools import corr_att_data
-from .Charts.Chart import Chart
+
+from .About import version
+from .Calibration import Calibration
 from .Charts import (
     CapacitanceChart,
     CombinedLogMagChart,
     GroupDelayChart,
     InductanceChart,
     LogMagChart,
-    PhaseChart,
     MagnitudeChart,
     MagnitudeZChart,
-    MagnitudeZShuntChart,
     MagnitudeZSeriesChart,
-    QualityFactorChart,
-    VSWRChart,
+    MagnitudeZShuntChart,
     PermeabilityChart,
+    PhaseChart,
     PolarChart,
+    QualityFactorChart,
     RealImaginaryMuChart,
     RealImaginaryZChart,
-    RealImaginaryZShuntChart,
     RealImaginaryZSeriesChart,
+    RealImaginaryZShuntChart,
     SmithChart,
     SParameterChart,
     TDRChart,
+    VSWRChart,
 )
-from .Calibration import Calibration
-from .Marker.Widget import Marker
+from .Charts.Chart import Chart
+from .Controls.MarkerControl import MarkerControl
+from .Controls.SerialControl import SerialControl
+from .Controls.SweepControl import SweepControl
+from .Formatting import format_frequency, format_gain, format_vswr
+from .Hardware.Hardware import Interface
+from .Hardware.VNA import VNA
 from .Marker.Delta import DeltaMarker
-from .SweepWorker import SweepWorker
+from .Marker.Widget import Marker
+from .RFTools import corr_att_data
 from .Settings.Bands import BandsModel
 from .Settings.Sweep import Sweep
+from .SweepWorker import SweepWorker
 from .Touchstone import Touchstone
-from .About import version
+from .Windows import (
+    AboutWindow,
+    AnalysisWindow,
+    CalibrationWindow,
+    DeviceSettingsWindow,
+    DisplaySettingsWindow,
+    FilesWindow,
+    SweepSettingsWindow,
+    TDRWindow,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -86,9 +87,9 @@ class Communicate(QObject):
 
 class NanoVNASaver(QWidget):
     version = version
-    scaleFactor = 1
+    scale_factor = 1.0
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.communicate = Communicate()
         self.s21att = 0.0
@@ -114,7 +115,7 @@ class NanoVNASaver(QWidget):
 
         self.worker.signals.updated.connect(self.dataUpdated)
         self.worker.signals.finished.connect(self.sweepFinished)
-        self.worker.signals.sweepError.connect(self.showSweepError)
+        self.worker.signals.sweep_error.connect(self.showSweepError)
 
         self.markers = []
         self.marker_ref = False
@@ -131,7 +132,7 @@ class NanoVNASaver(QWidget):
         self.bands = BandsModel()
 
         self.interface = Interface("serial", "None")
-        self.vna = VNA(self.interface)
+        self.vna: type[VNA] = VNA(self.interface)
 
         self.dataLock = threading.Lock()
         self.data = Touchstone()
@@ -241,7 +242,7 @@ class NanoVNASaver(QWidget):
         self.subscribing_charts.append(self.tdr_chart)
 
         for c in self.subscribing_charts:
-            c.popoutRequested.connect(self.popoutChart)
+            c.popout_requested.connect(self.popoutChart)
 
         self.charts_layout = QtWidgets.QGridLayout()
 
@@ -535,7 +536,7 @@ class NanoVNASaver(QWidget):
                 else:
                     logger.warning("No reference data for marker")
 
-            elif Marker.count() >= 2:
+            elif Marker.count() >= 2:  # noqa: PLR2004
                 m2 = self.markers[1]
 
             if m2 is None:
@@ -681,7 +682,7 @@ class NanoVNASaver(QWidget):
             self.s21charts.append(new_chart)
         if chart in self.combinedCharts:
             self.combinedCharts.append(new_chart)
-        new_chart.popoutRequested.connect(self.popoutChart)
+        new_chart.popout_requested.connect(self.popoutChart)
         return new_chart
 
     def closeEvent(self, a0: QtGui.QCloseEvent) -> None:
@@ -710,17 +711,17 @@ class NanoVNASaver(QWidget):
         standard_string = "0.123456789 0.123456789 MHz \N{OHM SIGN}"
         new_width = qf_new.horizontalAdvance(standard_string)
         old_width = qf_normal.horizontalAdvance(standard_string)
-        self.scaleFactor = new_width / old_width
+        self.scale_factor = new_width / old_width
         logger.debug(
             "New font width: %f, normal font: %f, factor: %f",
             new_width,
             old_width,
-            self.scaleFactor,
+            self.scale_factor,
         )
         # TODO: Update all the fixed widths to account for the scaling
         for m in self.markers:
             m.get_data_layout().setFont(font)
-            m.setScale(self.scaleFactor)
+            m.setScale(self.scale_factor)
 
     def update_sweep_title(self):
         for c in self.subscribing_charts:
