@@ -1,8 +1,8 @@
 #  NanoVNASaver
 #
 #  A python program to view and export Touchstone data from a NanoVNA
-#  Copyright (C) 2019, 2020  Rune B. Broberg
-#  Copyright (C) 2020,2021 NanoVNA-Saver Authors
+#  Copyright (C) 2019, 2020 Rune B. Broberg
+#  Copyright (C) 2020-2024 NanoVNA-Saver Authors
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import logging
 
-from PyQt6 import QtWidgets, QtCore, QtGui
+from PyQt6 import QtCore, QtGui, QtWidgets
 
 logger = logging.getLogger(__name__)
 
@@ -45,7 +45,7 @@ class BandsWindow(QtWidgets.QWidget):
 
         btn_add_row = QtWidgets.QPushButton("Add row")
         btn_delete_row = QtWidgets.QPushButton("Delete row")
-        btn_reset_bands = QtWidgets.QPushButton("Reset bands")
+        btn_reset_bands = QtWidgets.QPushButton("Reset bands/Select region")
         btn_layout = QtWidgets.QHBoxLayout()
         btn_layout.addWidget(btn_add_row)
         btn_layout.addWidget(btn_delete_row)
@@ -62,12 +62,39 @@ class BandsWindow(QtWidgets.QWidget):
             self.app.bands.removeRow(row.row())
 
     def resetBands(self):
-        confirm = QtWidgets.QMessageBox(
+        confirmBox = QtWidgets.QMessageBox(
             QtWidgets.QMessageBox.Icon.Warning,
             "Confirm reset",
             "Are you sure you want to reset the bands to default?",
-            QtWidgets.QMessageBox.StandardButton.Yes
-            | QtWidgets.QMessageBox.StandardButton.Cancel,
-        ).exec()
-        if confirm == QtWidgets.QMessageBox.StandardButton.Yes:
-            self.app.bands.resetBands()
+            QtWidgets.QMessageBox.StandardButton.Cancel,
+        )
+        region_1_defaults_button = QtWidgets.QPushButton(
+            "Reset to Region 1 defaults", confirmBox
+        )
+        region_2_defaults_button = QtWidgets.QPushButton(
+            "Reset to Region 2 defaults", confirmBox
+        )
+        region_3_defaults_button = QtWidgets.QPushButton(
+            "Reset to Region 3 defaults", confirmBox
+        )
+        confirmBox.addButton(
+            region_1_defaults_button,
+            QtWidgets.QMessageBox.ButtonRole.AcceptRole,
+        )
+        confirmBox.addButton(
+            region_2_defaults_button,
+            QtWidgets.QMessageBox.ButtonRole.AcceptRole,
+        )
+        confirmBox.addButton(
+            region_3_defaults_button,
+            QtWidgets.QMessageBox.ButtonRole.AcceptRole,
+        )
+        confirmBox.exec()
+
+        clicked_button = confirmBox.clickedButton()
+        if clicked_button == region_1_defaults_button:
+            self.app.bands.resetBands(1)
+        elif clicked_button == region_2_defaults_button:
+            self.app.bands.resetBands(2)
+        elif clicked_button == region_3_defaults_button:
+            self.app.bands.resetBands(3)
