@@ -20,10 +20,11 @@
 import logging
 from functools import partial
 
-from PyQt6 import QtWidgets, QtCore, QtGui
+from PyQt6 import QtCore, QtGui, QtWidgets
 
 from NanoVNASaver.Calibration import Calibration
 from NanoVNASaver.Settings.Sweep import SweepMode
+from NanoVNASaver.Touchstone import Touchstone
 from NanoVNASaver.Windows.Defaults import make_scrollable
 
 logger = logging.getLogger(__name__)
@@ -41,7 +42,7 @@ def getFloatValue(text: str) -> float:
 
 
 class CalibrationWindow(QtWidgets.QWidget):
-    nextStep = -1
+    next_step = -1
 
     def __init__(self, app: QtWidgets.QWidget):
         super().__init__()
@@ -165,10 +166,37 @@ class CalibrationWindow(QtWidgets.QWidget):
 
         cal_standard_box = QtWidgets.QGroupBox("Calibration standards")
         cal_standard_layout = QtWidgets.QFormLayout(cal_standard_box)
-        self.use_ideal_values = QtWidgets.QCheckBox("Use ideal values")
+        self.use_ideal_values = QtWidgets.QRadioButton("Use ideal values")
+        self.use_s1p_files = QtWidgets.QRadioButton("Use s1p files")
+        self.use_coefficients = QtWidgets.QRadioButton("Use coefficients")
+
         self.use_ideal_values.setChecked(True)
-        self.use_ideal_values.stateChanged.connect(self.idealCheckboxChanged)
-        cal_standard_layout.addRow(self.use_ideal_values)
+        self.radio_group = QtWidgets.QButtonGroup(self)
+        self.radio_group.addButton(self.use_ideal_values)
+        self.radio_group.addButton(self.use_s1p_files)
+        self.radio_group.addButton(self.use_coefficients)
+        self.radio_group.buttonClicked.connect(self.calStandardChanged)
+
+        self.radio_layout = QtWidgets.QHBoxLayout()
+        self.radio_layout.addWidget(self.use_ideal_values)
+        self.radio_layout.addWidget(self.use_s1p_files)
+        self.radio_layout.addWidget(self.use_coefficients)
+        cal_standard_layout.addRow(self.radio_layout)
+
+        self.file_button_short = QtWidgets.QPushButton("Short S1P file")
+        self.file_button_open = QtWidgets.QPushButton("Open S1P file")
+        self.file_button_load = QtWidgets.QPushButton("Load S1P file")
+        self.file_button_short.setEnabled(False)
+        self.file_button_open.setEnabled(False)
+        self.file_button_load.setEnabled(False)
+
+        cal_standard_layout.addRow(self.file_button_short)
+        cal_standard_layout.addRow(self.file_button_open)
+        cal_standard_layout.addRow(self.file_button_load)
+
+        self.file_button_open.clicked.connect(self.select_file_open)
+        self.file_button_short.clicked.connect(self.select_file_short)
+        self.file_button_load.clicked.connect(self.select_file_load)
 
         self.cal_short_box = QtWidgets.QGroupBox("Short")
         cal_short_form = QtWidgets.QFormLayout(self.cal_short_box)
@@ -264,6 +292,9 @@ class CalibrationWindow(QtWidgets.QWidget):
 
         cal_standard_layout.addWidget(self.cal_standard_save_box)
         right_layout.addWidget(cal_standard_box)
+        self.open_touchstone = None
+        self.short_touchstone = None
+        self.load_touchstone = None
 
     def checkExpertUser(self):
         if not self.app.settings.value("ExpertCalibrationUser", False, bool):
@@ -499,6 +530,9 @@ class CalibrationWindow(QtWidgets.QWidget):
         self.calibration_status_label.setText("Device calibration")
         self.calibration_source_label.setText("Device")
         self.notes_textedit.clear()
+        self.short_touchstone = None
+        self.open_touchstone = None
+        self.load_touchstone = None
 
         if len(self.app.worker.rawData11) > 0:
             # There's raw data, so we can get corrected data
@@ -546,16 +580,16 @@ class CalibrationWindow(QtWidgets.QWidget):
             )
             return
 
-        cal_element.short_is_ideal = True
-        cal_element.open_is_ideal = True
-        cal_element.load_is_ideal = True
+        cal_element.short_state = "IDEAL"
+        cal_element.open_state = "IDEAL"
+        cal_element.load_state = "IDEAL"
         cal_element.through_is_ideal = True
 
         # TODO: all ideal or not?
-        if not self.use_ideal_values.isChecked():
-            cal_element.short_is_ideal = False
-            cal_element.open_is_ideal = False
-            cal_element.load_is_ideal = False
+        if self.radio_group.checkedButton() == self.use_coefficients:
+            cal_element.short_state = "COEFF"
+            cal_element.open_state = "COEFF"
+            cal_element.load_state = "COEFF"
             cal_element.through_is_ideal = False
 
             # We are using custom calibration standards
@@ -606,6 +640,20 @@ class CalibrationWindow(QtWidgets.QWidget):
             cal_element.through_length = (
                 getFloatValue(self.through_length.text()) / 1.0e12
             )
+        elif self.radio_group.checkedButton() == self.use_s1p_files:
+            if self.short_touchstone is not None:
+                cal_element.short_state = "FILE"
+                cal_element.short_touchstone = self.short_touchstone
+            if self.open_touchstone is not None:
+                cal_element.open_state = "FILE"
+                cal_element.open_touchstone = self.open_touchstone
+            if self.load_touchstone is not None:
+                cal_element.load_state = "FILE"
+                cal_element.load_touchstone = self.load_touchstone
+            cal_element.through_is_ideal = False
+            cal_element.through_length = (
+                getFloatValue(self.through_length.text()) / 1.0e12
+            )
 
         logger.debug("Attempting calibration calculation.")
         try:
@@ -704,14 +752,34 @@ class CalibrationWindow(QtWidgets.QWidget):
             logger.error("Calibration save failed!")
             self.app.showError("Calibration save failed.")
 
-    def idealCheckboxChanged(self):
-        self.cal_short_box.setDisabled(self.use_ideal_values.isChecked())
-        self.cal_open_box.setDisabled(self.use_ideal_values.isChecked())
-        self.cal_load_box.setDisabled(self.use_ideal_values.isChecked())
-        self.cal_through_box.setDisabled(self.use_ideal_values.isChecked())
-        self.cal_standard_save_box.setDisabled(
-            self.use_ideal_values.isChecked()
-        )
+    def calStandardChanged(self, button):
+        if button == self.use_ideal_values:
+            self.cal_short_box.setDisabled(True)
+            self.cal_open_box.setDisabled(True)
+            self.cal_load_box.setDisabled(True)
+            self.cal_through_box.setDisabled(True)
+            self.cal_standard_save_box.setDisabled(True)
+            self.file_button_short.setDisabled(True)
+            self.file_button_open.setDisabled(True)
+            self.file_button_load.setDisabled(True)
+        elif button == self.use_s1p_files:
+            self.cal_short_box.setDisabled(True)
+            self.cal_open_box.setDisabled(True)
+            self.cal_load_box.setDisabled(True)
+            self.cal_through_box.setDisabled(False)
+            self.cal_standard_save_box.setDisabled(True)
+            self.file_button_short.setDisabled(False)
+            self.file_button_open.setDisabled(False)
+            self.file_button_load.setDisabled(False)
+        elif button == self.use_coefficients:
+            self.cal_short_box.setDisabled(False)
+            self.cal_open_box.setDisabled(False)
+            self.cal_load_box.setDisabled(False)
+            self.cal_through_box.setDisabled(False)
+            self.cal_standard_save_box.setDisabled(False)
+            self.file_button_short.setDisabled(True)
+            self.file_button_open.setDisabled(True)
+            self.file_button_load.setDisabled(True)
 
     def automaticCalibration(self):
         self.btn_automatic.setDisabled(True)
@@ -782,22 +850,22 @@ class CalibrationWindow(QtWidgets.QWidget):
             return
         self.reset()
         self.app.calibration.source = "Calibration assistant"
-        self.nextStep = 0
+        self.next_step = 0
         self.app.worker.signals.finished.connect(self.automaticCalibrationStep)
         self.app.sweep_start()
         return
 
     def automaticCalibrationStep(self):
-        if self.nextStep == -1:
+        if self.next_step == -1:
             self.app.worker.signals.finished.disconnect(
                 self.automaticCalibrationStep
             )
             return
 
-        if self.nextStep == 0:
+        if self.next_step == 0:
             # Short
             self.cal_save("short")
-            self.nextStep = 1
+            self.next_step = 1
 
             open_step = QtWidgets.QMessageBox(
                 QtWidgets.QMessageBox.Icon.Information,
@@ -815,7 +883,7 @@ class CalibrationWindow(QtWidgets.QWidget):
 
             response = open_step.exec()
             if response != QtWidgets.QMessageBox.StandardButton.Ok:
-                self.nextStep = -1
+                self.next_step = -1
                 self.btn_automatic.setDisabled(False)
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
@@ -824,10 +892,10 @@ class CalibrationWindow(QtWidgets.QWidget):
             self.app.sweep_start()
             return
 
-        if self.nextStep == 1:
+        if self.next_step == 1:
             # Open
             self.cal_save("open")
-            self.nextStep = 2
+            self.next_step = 2
             load_step = QtWidgets.QMessageBox(
                 QtWidgets.QMessageBox.Icon.Information,
                 "Calibrate load",
@@ -843,7 +911,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             response = load_step.exec()
             if response != QtWidgets.QMessageBox.StandardButton.Ok:
                 self.btn_automatic.setDisabled(False)
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -851,10 +919,10 @@ class CalibrationWindow(QtWidgets.QWidget):
             self.app.sweep_start()
             return
 
-        if self.nextStep == 2:
+        if self.next_step == 2:  # noqa: PLR2004
             # Load
             self.cal_save("load")
-            self.nextStep = 3
+            self.next_step = 3
             continue_step = QtWidgets.QMessageBox(
                 QtWidgets.QMessageBox.Icon.Information,
                 "1-port calibration complete",
@@ -873,7 +941,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             response = continue_step.exec()
             if response == QtWidgets.QMessageBox.StandardButton.Apply:
                 self.calculate()
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -881,7 +949,7 @@ class CalibrationWindow(QtWidgets.QWidget):
                 return
             if response != QtWidgets.QMessageBox.StandardButton.Yes:
                 self.btn_automatic.setDisabled(False)
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -904,7 +972,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             response = isolation_step.exec()
             if response != QtWidgets.QMessageBox.StandardButton.Ok:
                 self.btn_automatic.setDisabled(False)
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -912,10 +980,10 @@ class CalibrationWindow(QtWidgets.QWidget):
             self.app.sweep_start()
             return
 
-        if self.nextStep == 3:
+        if self.next_step == 3:  # noqa: PLR2004
             # Isolation
             self.cal_save("isolation")
-            self.nextStep = 4
+            self.next_step = 4
             through_step = QtWidgets.QMessageBox(
                 QtWidgets.QMessageBox.Icon.Information,
                 "Calibrate through",
@@ -931,7 +999,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             response = through_step.exec()
             if response != QtWidgets.QMessageBox.StandardButton.Ok:
                 self.btn_automatic.setDisabled(False)
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -939,7 +1007,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             self.app.sweep_start()
             return
 
-        if self.nextStep == 4:
+        if self.next_step == 4:  # noqa: PLR2004
             # Done
             self.cal_save("thrurefl")
             self.cal_save("through")
@@ -957,7 +1025,7 @@ class CalibrationWindow(QtWidgets.QWidget):
             response = apply_step.exec()
             if response != QtWidgets.QMessageBox.StandardButton.Apply:
                 self.btn_automatic.setDisabled(False)
-                self.nextStep = -1
+                self.next_step = -1
                 self.app.worker.signals.finished.disconnect(
                     self.automaticCalibrationStep
                 )
@@ -965,8 +1033,32 @@ class CalibrationWindow(QtWidgets.QWidget):
 
             self.calculate()
             self.btn_automatic.setDisabled(False)
-            self.nextStep = -1
+            self.next_step = -1
             self.app.worker.signals.finished.disconnect(
                 self.automaticCalibrationStep
             )
             return
+
+    def select_file_open(self):
+        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
+            self, "Select Open S1P", "", "Touchstone Files (*.s1p)"
+        )
+        if filename != "":
+            self.open_touchstone = Touchstone(filename)
+            self.open_touchstone.load()
+
+    def select_file_short(self):
+        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
+            self, "Select Short S1P", "", "Touchstone Files (*.s1p)"
+        )
+        if filename != "":
+            self.short_touchstone = Touchstone(filename)
+            self.short_touchstone.load()
+
+    def select_file_load(self):
+        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
+            self, "Select Load S1P", "", "Touchstone Files (*.s1p)"
+        )
+        if filename != "":
+            self.load_touchstone = Touchstone(filename)
+            self.load_touchstone.load()
